using System;
using System.Linq;
using System.Xml;
using System.Xml.Linq;
using System.Collections.Generic;

using Sce.PlayStation.Core.Graphics;
using Sce.PlayStation.HighLevel.GameEngine2D;
using Sce.PlayStation.HighLevel.GameEngine2D.Base;


namespace StreetDreams
{
	public class SpriteSheetHandler
	{
		private TextureInfo textureInfo;
		private Texture2D texture;
		private System.Collections.Generic.Dictionary<string,Sce.PlayStation.HighLevel.GameEngine2D.Base.Vector2i> sprites;
		private int width,height;
		public SpriteSheetHandler(string imageFilePath, string xmlFilePath, int cols, int rows, int width, int height)
		{
			this.width = width;
			this.height = height;
			XDocument doc = XDocument.Load(xmlFilePath);
			var lines = from sprite in doc.Root.Elements("sprite")
				select new
			{
				Name = sprite.Attribute("n").Value,
      			X1 = (int)sprite.Attribute ("x"),
      			Y1 = (int)sprite.Attribute ("y"),
      			Height = (int)sprite.Attribute ("h"),
     		    Width = (int)sprite.Attribute("w")
			};
			sprites = new Dictionary<string, Sce.PlayStation.HighLevel.GameEngine2D.Base.Vector2i>();
			foreach(var curLine in lines)
			{
				sprites.Add(curLine.Name, new Vector2i((curLine.X1/curLine.Width), rows-1-(curLine.Y1/curLine.Height)));
			}
			texture = new Texture2D(imageFilePath,false);
			textureInfo = new TextureInfo(texture, new Vector2i(cols,rows));
		}
		
		~SpriteSheetHandler()
		{
			texture.Dispose();
			textureInfo.Dispose();
		}
		
		public Sce.PlayStation.HighLevel.GameEngine2D.SpriteTile Get(int x, int y)
		{
			var spriteTile = new SpriteTile(textureInfo);
			spriteTile.TileIndex2D = new Vector2i(x,y);
			spriteTile.Quad.S = new Sce.PlayStation.Core.Vector2(this.width,this.height);
			return spriteTile;
		}
		
		public Sce.PlayStation.HighLevel.GameEngine2D.SpriteTile Get(string name)
		{
			return Get(sprites[name].X,sprites[name].Y);
		}
			
	}
}

